### Machine Learning - just do it ! mellow got your back. 
###### mellow is the python package contains well known machine learning algorithms.
It provides:
- most popular machine learning algorithms
- sophisticated utility functions useful in these algorithms
- and much more

Often we Developers/Students feel hesitation to implement the machine learning algorithms because</br>
either they find it hefty or time consuming, what we believe is understanding the machine learning</br>
is much more important than converting it into code. So we come up with this beautiful library mellow</br>
to help you out.
